
;--------------------------------------------------------------------------
;                ͻ
;                 ESQUEMA DE CONEXIONES PIC16F84A 
;                ͼ
;   
;                        __________________
;                        |      \__/      |
;                       O| 1           18 |O             
;                        |                |
;                       O| 2    PIC    17 |O                                  
;                        |    16F84A      |      
;             [4] RESET O| 3           16 |O---|  
;                        |                |   [|] 4 Mhz/8Mhz/12Mhz
;       |---- [1] +5VCC O| 4______     15 |O---|
;       |                |        \       |       27pf
;       |     [8] MASA  O|-5-||----\___14 |O +5VCC [1]
;       \                |   100n        |
;       /    [2] DVDOUT O| 6  opcional 13 |O MOTOR CD    [7] (pin 23 BA6664)     
;  100k \                |                |
;       /     [3] DVDIN O| 7           12 |O TX_SCEE     [6]          
;       \                |                | 
;       |-[10] PULSADOR O| 8           11 |O MOTOR PULSE [5]       
;     | o                |                |
;   --|       		O| 9           10 |O SHORT BRAKE  [9] (PIN 18 BA6664)       
;     | o                |                |
;       |                ------------------
;      --- MASA

;NOTA: CONEXIONES PARA EL MODCHIPX

;TODOS LOS PUNTOS IGUAL QUE EL MONTAJE DEL 8MOD, EXCEPTO [7] [9] Y [10]
;[1] +5VCC - SIN COMENTARIOS 
;[2] DVD_OUT - ES IGUAL A 1 CUANDO LA BANDEJA DEL DVD ESTA SALIENDO 
;[3] DVD_IN - ES IGUAL A 1 CUANDO LA BANDEJA DEL DVD ESTA ENTRANDO 
;[4] PS2_RESET - ES IGUAL A 0 CUANDO PULSAMOS EL RESET DE LA PS2 
;[5] MOTOR_PULSE - ENVIO DE PULSOS AL MOTOR DE LA BANDEJA DEL DVD 
;[6] TX_SCEE - ES POR DONDE TRANSMITE VIA SERIE "SCEE" 
;[7] MOTOR_CD - SEAL QUE AL PONERSE A 0, PARA EL MOTOR DEL CD (NECESARIO EN V4)
;[8] MASA - SIN COMENTARIOS 
;[9] SHORT BRAKE- SEAL QUE AL PONERSE A 1 FRENA EL MOTOR DEL CD (NECESARIO EN V4)
; EN EL PIN 8 ES OBLIGATORIO PONER UNA RESISTENCIA DE 100 K A +5V, INCLUSO SI NO INSTALAMOS EL PULSADOR


;NOTA2: LOS CONDENSADORES DE 27 PF, SON OPCIONALES. YO TENGO MONTADO UN CRISTAL DE 12 MHZ, 
; SIN CONDENSADORES Y NO HAY PROBLEMA. TAMBIEN SE PUEDE PONER UNO DE 100nF ENTRE 5V Y MASA


;*****************************************************************************************************************************
;ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION
;*****************************************************************************************************************************

; PROCESADOR A EMPLEAR PIC16F84A, CRISTAL 12 MHZ (TAMBIEN SE PUEDE PONER A 4 Mhz) EUROPA


F84A EQU 1          ;0=PIC16F84 1=PIC16F84A TIPO
F12MHZ EQU 1        ;0=4MHZ 1=12MHZ         FRECUENCIA DEL CRISTAL
FHIGH  EQU 1        ; SI F12MHZ ENTONCES SI 0- 8MHZ  1-12MHZ (JEJE UN POCO REBUSCADO NO?)  
ZONA EQU 1          ;0-EUROPA 1-AMERICA


 IF        F84A
 list      p=16F84A
 include   "p16F84A.inc"
 ELSE
 list      p=16F84
 include   "p16F84.inc"
 ENDIF

;ͻ
; SIN POWER ON RESET, SIN PROTEJER, SIN WASDOG Y CON OSCILADOR EXTERNO 
;ͼ
 __FUSES _PWRTE_OFF & _CP_OFF & _WDT_OFF & _XT_OSC

;ͻ
; NOTACION DECIMAL 
;ͼ
 radix   dec
;--------------------------------------------------------------------------

;ͻ
; VARIABLES DE RAM INTERNA 
;ͼ
 cblock 0x0c
        RAM_0C  ;Contador pausa
        RAM_0D  ;Contador
        RAM_0E  ;Contador pausa
        RAM_0F  ;Cantidad de bytes a enviar de la tabla
        RAM_10  ;Cantidad de bits a enviar del byte
        RAM_11  ;Contador W en pausa Wx199
        RAM_12  ;Contador 199 en pausa Wx199
        RAM_13  ;Byte leido de la tabla
        RAM_14  ;Puntero del byte de la tabla
        RAM_15  ;Mascara del estado de los bits del puerto A
        RAM_16  ;Mascara del estado de los bits del puerto B
      ;  RAM_0B  ; contador antiguo
        endc

;///////////////////////////////////
;/ FUNCIONAMIENTO
;///////////////////////////////////
;NUEVO: PULSADOR. El pulsador actua tanto en 1) 2) 3), pasando al modo 3) (METODO EA).
;       PARADA DEL CD: Usando las nuevas seales, se consigue que salga el CD totalmente parado
;       Correccion de tiempo para permitir los originales en consola Americana, que no entraban
     
; 1) MODO PARA COPIAS Y ORIGINALES: PULSAR BREVEMENTE (MENOS 1 SEG) EL RESET, PARA ENCENDER LA CONSOLA 
;  O ENCENDER EXPULSANDO LA BANDEJA
; 2) METODO EA AUTOMATICO:ENCENDER PULSANDO UN PAR DE SEGUNDOS Y MENOS DE 7.5. cUANDO SE CARGUE EL XTREME O AR2, 
;    A LOS POCOS SEGUNDOS SE EXPULS LA BANDEJA Y 8 SEG DESPUES SE CIERRA
; 3) METODO EA MANUAL: ENCENDER PULSANDO RESET DURANDTE MAS DE 7.5 SEGUNDOS, CUANDO SE CARGUE EL XTREM O AR2,
;    SOLTAR EL RESET Y LA BANDEJA SALDRA DURANTE 8 SEGUNDOS
; NOTA: EN EL METODO EA, SI EXPULSAMOS LA BANDEJA PULSANDO EL BOTON, SE PRODUCE LA ACTIVACION DEL CHIP (MANDA EL SCEE). 
;       ESTO ESTA BIEN POR SI EL JUEGO SE ATASCA.

; 4) METODO CHIP APAGADO: ENCENDER PULSANDO RESET DURANTE DOS SEGUNDOS (EA AUTOMATICO), SOLTAR Y PULSAR NUEVAMENTE 
;    EL RESET DE FORMA BREVE. eL CHIP PERMANECE A LA ESPERA HASTA QUE SE PRODUZCA OTRO RESET (MODO PARA ORIGINALES CONFLICTIVOS)

; NOTAS SOBRE XTREME/AR2: CUANDO SE CAMBIE EL DISCO EN EL MODO PARA COPIAS/ORIGINALES, ESPERAR UNOS SEGUNDOS A QUE LA PS2
;   RECONOZCA EL CD ANTES DE PULSAR X (ES MEJOR ASI)


;--------------------------------------------------------------------------

;ͻ
; DEFINICION DE LOS PINES DEL PIC 
;ͼ
       
        #define  PS2_RESET PORTA,4
     	#define  TX_SCEE   PORTB,6
	#define  DVD_IN    PORTB,1        
;--------------------------------------------------------------------------

;ͻ
; VECTOR DE RESET 
;ͼ
	org	0x0
        goto    COMIENZO        ;SALTA LA COMIENZO DEL PROGRAMA
;--------------------------------------------------------------------------

;--------------------------------------------------------------------------

;ͻ
; VECTOR DE INTERRUPCION 
;ͼ
        org     0x4
        retfie

TABLA   
	addwf   PCL,F           ;TABLA PARA LA PS2 EUROPEA
 IF ZONA
	retlw   'S'
        retlw   'C'
        retlw   'E'
        retlw   'A'
 ELSE
        retlw   'S'
        retlw   'C'
        retlw   'E'
        retlw   'E'
 ENDIF
 IF 0
        
        retlw   'S'
        retlw   'C'
        retlw   'E'
        retlw   'I'
 ENDIF

;--------------------------------------------------------------------------
	retlw   ' '
        retlw   'M'
        retlw   'O'
        retlw   'D'
        retlw   'C'
        retlw   'H'
        retlw   'I'
	retlw   'P'
	retlw   'X'
        
        retlw   ' '
        retlw   'B'
        retlw   'Y'
        retlw   ' '
        retlw   'U'
        retlw   'S'
        retlw   'B'
        retlw   ' '
        retlw   'V'
        retlw   'K'
;--------------------------------------------------------------------------

;--------------------------------------------------------------------------

;ͻ
; COMIENZO DEL PROGRAMA 
;ͼ
COMIENZO
        movlw   b'11000010'     ;CONFIGURA TMR0 PRESCALER = 1:8
        option                  ;OSCILADOR = 4MHZ
       
        movlw   b'11111111'     ;INICIALIZA TODOS LOS PUERTOS
        movwf   RAM_15          ;EN ALTO Y SUS MASCARAS RAM_15 Y RAM_16
        movwf   RAM_16          ;
        tris    PORTA           ;
        tris    PORTB           ;
        movlw   2               ;100 MILISEGUNDOS
        movwf   RAM_0D          ;
ETI_107 call    PAUSA50MSG      ;       +
        decfsz  RAM_0D,F        ;
        goto    ETI_107         ;
        movlw   6               ;300 MILISEGUNDOS
        movwf   RAM_0D          ;
ETI_10C call    PAUSA50MSG      ;       +
        decfsz  RAM_0D,F        ;
        goto    ETI_10C         ;
        movlw   14              ;14 MILISEGUNDOS
        call    PAUSAWX1MSG     ;
;--------------------------------------------------------------------------

;ͻ
; LECTURA DE LAS 3 OPCIONES CON EL PULSADOR DE RESET DE LA CONSOLA 
;ͼ
;OPCION2 SI EL RESET NO HA SIDO PULSADO
;-----------------------------------

        movlw   20             ;
        movwf   RAM_0D          ;
ETI_115a 
	btfsc   PS2_RESET          ; 
        goto    OPCION2        ;SALTA A OPCION2 AL LEVANTAR EL RESET
        call    PAUSA50MSG      ;
        decfsz  RAM_0D,F        ;
        goto    ETI_115a

;OPCION4 EL RESET HA SIDO PULSADO Y SE HA SOLTADO ANTES DE 7,5 SEGUNDOS
;----------------------------------------------------------------------
        movlw   130             ;
        movwf   RAM_0D          ;
ETI_115 btfsc   PS2_RESET          ; 
        goto    OPCION4         ;SALTA A OPCION4 AL LEVANTAR EL RESET
        call    PAUSA50MSG      ;
        decfsz  RAM_0D,F        ;
        goto    ETI_115         ;
	 
;OPCION3 EL RESET HA SIDO PULSADO Y NO SE HA SOLTADO ANTES DE 7,5 SEGUNDOS
;-------------------------------------------------------------------------
ETI_ca 
	btfsc   PS2_RESET     
    	goto    OPCION3         ;CUANDO SOLTEMOS RESET SALTA A OPCION3 (metodo EA)
      call    PAUSA50MSG      ;
      goto ETI_ca
;--------------------------------------------------------------------------


;ͻ
; OPCION 1 (RESET NO PULSADO) EL MODCHIP SE         
; DESHABILITA Y SOLO PODEMOS USAR JUEGOS ORIGINALES 
;ͼ
OPCION1
        call    PAUSA50MSG      ;
	btfss   PS2_RESET           ;SI EL RESET ESTA PULSADO, ESPERA A SOLTARLO
        goto    OPCION1   
        call    PAUSA50MSG      ;
	btfss   PS2_RESET           ;SI EL RESET ESTA PULSADO, ESPERA A SOLTARLO
        goto    OPCION1   
        movlw   b'11111111'     ;INICIALIZA TODOS LOS
        tris    PORTB            ;PUERTOS EN ALTO Y
OP_1     
	call    PAUSA50MSG      ;
        btfsc   PS2_RESET           ;SI EL RESET NO ESTA PULSADO
        goto    OP_1         ;SALTA A OPCION1 (en espera)
      ;OPCION EN RESET CON EL CHIP DESCONECTADO SALTA OPCION2
       
        goto OPCION2

;///////////////////////////////////////////
;//           METODO EA ESPECIAL          //
;///////////////////////////////////////////

OPCION4 
        call    PAUSA50MSG      ;
        btfss   PS2_RESET           ;SI EL RESET  ESTA PULSADO
        goto    OPCION4         ;SALTA A OPCION4
        call    PAUSA50MSG      ;
	btfss   PS2_RESET           ;SI EL RESET ESTA PULSADO, ESPERA A SOLTARLO
        goto    OPCION4   

        
; ESPERA 35 SEGUNDOS Y HAZ MODO EA     
        movlw   250               ;12,5 segundos
        movwf   RAM_0D          ;
       	
UNO    	call BOTON
        andlw 0xff
        btfss STATUS,Z
        goto OPCION3

        call    PAUSA50MSG      ; 
        btfss   PS2_RESET           ;SI EL RESET  ESTA PULSADO
        goto    OPCION1         ;SALTA A OPCION1 (desconecta el chip)
        btfsc   DVD_IN          ;ESPERA A QUE PULSEMOS LA APERTURA
        goto    OPCION2         ;PARA PASAR A MODO CHIP PSX
    
        decfsz  RAM_0D,F        ;
        goto    UNO         ;
     
         
        movlw   200               ;10  segundos
        movwf   RAM_0D          ;
DOS 	call BOTON
        andlw 0xff
        btfss STATUS,Z
        goto OPCION3
        call    PAUSA50MSG      ; 
        btfss   PS2_RESET           ;SI EL RESET  ESTA PULSADO
        goto    OPCION2         ;SALTA A OPCION2
        btfsc   DVD_IN          ;ESPERA A QUE PULSEMOS LA APERTURA
        goto    OPCION2         ;PARA PASAR A MODO CHIP PSX
        decfsz  RAM_0D,F        ;
        goto    DOS         ;
        movlw   200               ;10 segundos
        movwf   RAM_0D          ;
TRES 	call BOTON
        andlw 0xff
        btfss STATUS,Z
        goto OPCION3
        call    PAUSA50MSG      ; 
        btfss   PS2_RESET           ;SI EL RESET  ESTA PULSADO
        goto    OPCION2         ;SALTA A OPCION2
        btfsc   DVD_IN          ;ESPERA A QUE PULSEMOS LA APERTURA
        goto    OPCION2         ;PARA PASAR A MODO CHIP PSX
   
        decfsz  RAM_0D,F        ;
        goto    TRES         ;
        
        goto OPCION3           ; METODO EA
    
 




OPCION3
        call    PAUSA50MSG 
	btfss   PS2_RESET           ;SI EL RESET  ESTA PULSADO
        goto    OPCION3         ;SALTA A OPCION3
     
        call    PAUSA50MSG 
        btfss   PS2_RESET           ;SI EL RESET  ESTA PULSADO
        goto    OPCION3
       
           
        
        movlw   255             ;INICIALIZA RAM_16 Y TODOS
        movwf   RAM_16          ;LOS PUERTOS
        tris    PORTB            ;EN ALTO
        movwf   RAM_15          ;LOS PUERTOS
        tris    PORTA            ;EN ALTO


; sistema de apertura
OPEN
     



 
;        movlw   b'01111111'     ;   pone a 0 PORTB7 (pata 13)
;        movwf   PORTB            ;   esto pone a dormir el circuito
;        movlw   b'01111111'     ;   que controla el giro del CD
;       	tris 	PORTB
	
	movlw   b'01111111'     ;   pone a 0 PORTB7 (pata 13)
        movwf   PORTB            ;   esto pone a dormir el circuito
        movlw   b'11101111'     ;   que controla el giro del CD
       	tris 	PORTB




 
        movlw   15              ; FRENO PROGRESIVO (1 segundo y medio)
        movwf   RAM_0D         
ope_1 
        btfss   PS2_RESET          ;SALTA OPCION 2 SI SE PULSA
        goto    OPCION2         ;BOTON DE RESET
	movlw   b'01101111'     ;   que controla el giro del CD
       	tris 	PORTB
        movlw   50             ;
        call    PAUSAWX1MSG     ;                 "
	movlw   b'01111111'     ;   que controla el giro del CD
       	tris 	PORTB
        movlw   50             ;
        call    PAUSAWX1MSG     ;     
        decfsz  RAM_0D,F        ;                 "
        goto    ope_1         ;   
	movlw   25              ; FRENO PROGRESIVO (2,5 segundos)
        movwf   RAM_0D  
ope_1b 
        btfss   PS2_RESET          ;SALTA OPCION 2 SI SE PULSA
        goto    OPCION2         ;BOTON DE RESET
	movlw   b'01101111'     ;   que controla el giro del CD
       	tris 	PORTB
        movlw   75             ;
        call    PAUSAWX1MSG     ;                 "
	movlw   b'01111111'     ;   que controla el giro del CD
       	tris 	PORTB
        movlw   25             ;
        call    PAUSAWX1MSG     ;    
        decfsz  RAM_0D,F        ;                 "
        goto    ope_1b         ;   



	movlw   b'11111111'     ;   que controla el giro del CD
       	tris 	PORTB   

 
        movlw   80
        call Abrir                       

        movlw   32              ;PAUSA PARA QUE LA BANDEJA DEL DVD 
        movwf   RAM_0D          ;ESTE 8 SEGUNDOS ABIERTA Y NOS DE 
ETI_144 
        btfss   PS2_RESET          ;SALTA OPCION 2 SI SE PULSA
        goto    OPCION2         ;BOTON DE RESET

        movlw   250             ;TIEMPO A PONER EL JUEGO EN ELLA
        
        call    PAUSAWX1MSG     ;                 "
        decfsz  RAM_0D,F        ;                 "
        goto    ETI_144         ;                 "
        

        
        movlw   b'11111111'     ;   pone a 1 PORTB7 (pata 13)
        movwf   PORTB            ;   despierta el circuito
        movlw   b'11111111'     ;   que controla el giro del CD
	tris 	PORTB
        call Cerrar;


;/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
;// OPCION QUE HABILITA EL CHIP (MODO PSX) SI ES LO QUE QUEREMOS (NO HACE NADA HASTA QUE PULSAMOS RESET O EXPULSAR BANDEJA) //
;/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
ETI_500
        call BOTON
        andlw 0xff
        btfss STATUS,Z
        goto OPCION3
	btfss   PS2_RESET          ;SALTA OPCION 2 SI SE PULSA
        goto    OPCION2         ;BOTON DE RESET
        btfss   DVD_IN          ;ESPERA A QUE PULSEMOS LA APERTURA
        goto    ETI_500         ;DE LA BANDEJA DEL DVD O RESET 
        goto    OPCION2         ;PARA PASAR A MODO CHIP PSX
;--------------------------------------------------------------------------
Abrirlo
        movlw   16              ;EL MODCHIP FUERZA A LA CONSOLA
Abrir 
        movwf   RAM_0D          ;PARA QUE EXPULSE LA BANDEJA DEL DVD
ETI_132 
;	 movlw   b'00100100'     ;                 "
;        movwf   GPIO            ;                 "
;        movlw   b'11011010'     ;                 "
;        tris    GPIO            ;                 "

	movlw   b'00111001'     ;                 "
        movwf   PORTB           ;                 "
        movlw   b'01011110'     ;                 "
        tris    PORTB           ;                 "
	

        movlw   10              ;                 "
        call    PAUSAWX1MSG     ;                 "
       ;movlw   b'00100000'     ;                 "
       ;movwf   GPIO            ;                 "
       ;movlw   b'00011010'     ;                 "
       ;tris    GPIO            ;                 "

	movlw   b'00011001'     ;                 "
        movwf   PORTB           ;                 "
	movlw   b'01011110'     ;                 "
        tris    PORTB           ;                 "
	 
  
     movlw   10              ;                 "
        call    PAUSAWX1MSG     ;                 "
        decfsz  RAM_0D,F        ;                 "
        goto    ETI_132         ;                 "
        movlw   b'01111111'     ;                 "
        tris    PORTB           ;                 "
        
        retlw 1
Cerrar
	  movlw   80              ;EL MODCHIP FUERZA A LA CONSOLA
        movwf   RAM_0D          ;PARA QUE INTRODUZCA LA BANDEJA DEL DVD
ETI_14A 
;	movlw   b'00010100'     ;                 "
;        movwf   GPIO            ;                 "
;        movlw   b'11101011'     ;                 "
;        tris    GPIO            ;                 "

	movlw   b'00111010'     ;                 "
        movwf   PORTB            ;                 "
        movlw   b'11011101'     ;                 "
        tris    PORTB            ;                 "
        movlw   10              ;                 "
        call    PAUSAWX1MSG     ;                 "
;        movlw   b'00010000'     ;                 "
;        movwf   GPIO            ;                 "
;        movlw   b'11101011'     ;                 "
;        tris    GPIO            ;                 "
	movlw   b'00011010'     ;                 "
        movwf   PORTB           ;                 "
        movlw   b'11011101'     ;                 "
        tris    PORTB           ;                 "
        movlw   10              ;                 "
        call    PAUSAWX1MSG     ;                 "
        decfsz  RAM_0D,F        ;                 "
        goto    ETI_14A         ;                 "
;       movlw   b'00111111'     ;                 "
;       tris    GPIO            ;                 "

	movlw   b'11111111'     ;                 "
        tris    PORTB            ;                 "
        retlw 1
;	nop;

	


;--------------------------------------------------------------------------

;ͻ
; PAUSA DE (W x 1 SEGUNDO) 
;ͼ
PAUSAWX1SG
        movwf   RAM_0E          ;
ETI_P1B movlw   4               ; 
        movwf   RAM_0C          ; 
ETI_P1A movlw   250             ;
        call    PAUSAWX1MSG     ;
        decfsz  RAM_0C,F        ;
        goto    ETI_P1A         ;
        decfsz  RAM_0E,F        ;
        goto    ETI_P1B         ;
        return               
;ͻ
; PAUSA DE 50 MILISEGUNDOS 
;ͼ

PAUSA50MSG
        movlw   50              ;
;ͻ
; PAUSA DE (W x 1 MILISEGUNDO) 
;ͼ
PAUSAWX1MSG
        movwf   RAM_11          ;
ETI_042 movlw   199             ;
        movwf   RAM_12          ;
ETI_044 nop                     ;
        nop                    ;
 IF F12MHZ
 IF FHIGH
        nop
        nop
        nop
        nop
        nop
 ENDIF
        nop
        nop
        nop
        nop
        nop
 ENDIF
        decfsz  RAM_12,F        ;
        goto    ETI_044         ;
        nop     
 IF F12MHZ
 IF FHIGH
        nop
        nop
        nop
        nop
        nop
 ENDIF
        nop
        nop
        nop
        nop
        nop
 ENDIF	    
                   
        decfsz  RAM_11,F        ;
        goto    ETI_042         ;
        return                  ;
;--------------------------------------------------------------------------
OPCION2
       
        btfss   PS2_RESET           ;SI EL RESET ESTA PULSADO ESPERA A QUE SE SUELTE
        goto    OPCION2
        btfss   PS2_RESET           ;SI EL RESET ESTA PULSADO ESPERA A QUE SE SUELTE
        goto    OPCION2
         ;INICIALIZA PUERTOS   
        movlw   255 
        movf    RAM_15,W        ;
        tris    PORTA     
       
        movf    RAM_16,W        ;
        tris    PORTB          ;
        
       
        
        
BUCLEA2
        
 
; SEMICICLO DE ORIGINALES
       bsf     RAM_16,6   
       movf    RAM_16,W        ;
       tris    PORTB          ;
	 movlw   8             ;8 VECES
       movwf   RAM_0D         ;REPETIRA LA PAUSA (DEL TAMAO DE UNA TRANSMISION)
ETI_o
       movlw   250               ;                 "
       call    PAUSAWX1MSG  
	call BOTON
        andlw 0xff
        btfss STATUS,Z
        goto OPCION3
       btfss  PS2_RESET        ;SI EL RESET ESTA PULSADO
       goto OPCION2             ;CONECTA CHIP  
       decfsz  RAM_0D,F        ;
       goto    ETI_o
 
; SEMICICLO COPIAS (ENVIA SCEE) 
       movlw   8             ;8 VECES
       movwf   RAM_0D          ;REPETIRA LA TRANSMISION
ETI_122
   	call BOTON
        andlw 0xff
        btfss STATUS,Z
        goto OPCION3

       clrf    RAM_14          ;INICIALIZA PUNTERO A TABLA Y
       call    ENVIASCEE       ;TRANSMITE VIA SERIE 8 VECES 'SCEE
       btfss   PS2_RESET        ;SI EL RESET ESTA PULSADO
       goto OPCION2             ;CONECTA CHIP
    

	 decfsz  RAM_0D,F    
	 goto    ETI_122 
       goto BUCLEA2     


ENVIASCEE
        ; 250 milisegundos (lo que nos dice que se cargan 16 sectores a 1x que curioso verdad?)
       
        movlw   74              ;74 MILISEGUNDOS DE ESPACIO ENTRE
        call    PAUSAWX1MSG     ;ENTRE TRANSMISION Y TRANSMISION

        movlw   4               ;ENVIAREMOS 4 BYTES
        movwf   RAM_0F          ;DE LA TABLA
ETI_068
        movf    RAM_14,W        ;LEEMOS 1 BYTE DE
        call    TABLA           ;LA TABLA
        movwf   RAM_13          ;EN RAM_13
        comf    RAM_13,F        ;

        movlw   8               ;ENVIAREMOS 8
        movwf   RAM_10          ;BITS DE CADA BYTE

        bsf     RAM_16,6        ;ENVIA EL BIT DE START VIA SERIE
        movf    RAM_16,W        ;
        tris    PORTB           ;

        movlw   4               ;4 MILISEGUNDOS DEL ANCHO DEL BIT DE START
        call    PAUSAWX1MSG     ;

ETI_073
        rrf     RAM_13,F        ;ENVIA 1 BIT DEL BYTE VIA SERIE
        movlw   b'10111111'     ;
        movwf   PORTB           ;
        btfsc   STATUS,0        ;
        bsf     RAM_16,6        ;
        btfss   STATUS,0        ;
        bcf     RAM_16,6        ;
        movf    RAM_16,W        ;
        tris    PORTB           ;

        movlw   4               ;4 MILISEGUNDOS DEL ANCHO DEL BIT
        call    PAUSAWX1MSG     ;

        decfsz  RAM_10,F        ;CONTINUAMOS HASTA
        goto    ETI_073         ;ENVIAR LOS 8 BITS DEL BYTE

        bcf     RAM_16,6        ;ENVIA 2 BITS DE STOP
        movf    RAM_16,W        ;
        tris    PORTB           ;

        movlw   8               ;8 MILISEGUNDOS DEL ANCHO DE
        call    PAUSAWX1MSG     ;LOS 2 BITS DE STOP

	

        incf    RAM_14,F        ;INCREMENTA PUNTERO DE LA TABLA

        decfsz  RAM_0F,F        ;CONTINUA HASTA
        goto    ETI_068         ;ENVIAR LOS 4 BYTES DE LA TABLA
       
        return                  ;RETORNA



;// DETECTA SI SE HA PULSADO
BOTON   

        movlw 1
	call PAUSAWX1MSG
	btfsc PORTB,2
	retlw 0
	nop
	nop
	nop
	btfsc PORTB,2
	retlw 0
	retlw 0xff
      	
	end

